@@ -94,6 +94,7 @@ survey_mean_grouped_svy <- function(.svy, x, na.rm = FALSE,
                                     prop_method = c("logit", "likelihood",
                                                     "asin", "beta", "mean")) {
   if (missing(x)) {
+    if (proportion) stop("proportion does not work with factors.")
     survey_stat_factor(.svy, survey::svymean, na.rm, vartype, level)
   } else if (proportion) {
     survey_stat_grouped(.svy, survey::svyciprop, x, na.rm, vartype, level,
@@ -171,7 +172,7 @@ survey_total_grouped_svy <- function(.svy, x, na.rm = FALSE,
                                      level = 0.95) {
   if (!is.null(x)) survey_stat_grouped(.svy, survey::svytotal, x, na.rm,
                                        vartype, level)
-  else survey_stat_factor(.svy, survey::svytotal, na.rm, vartype)
+  else survey_stat_factor(.svy, survey::svytotal, na.rm, vartype, level)
 }
 
 
@@ -523,6 +524,11 @@ survey_stat_factor <- function(.svy, func, na.rm, vartype, level) {
 
   vartype <- c("coef", vartype)
 
+  if (length(level) > 1) {
+    warning("Only the first confidence level will be used")
+    level <- level[1]
+  }
+
   if (length(grps) > 0) {
     stat <- survey::svyby(survey::make.formula(peel),
                           survey::make.formula(grps),
